<template>
  <el-tree
    ref="tree"
    :check-strictly="false"
    :data="list"
    :props="defaultProps"
    node-key="id"
    show-checkbox
    @check-change="onCheckChange"
  />
</template>

<script>
export default {
  props: {
    value: {
      type: Array,
      default: () => [],
    },
    disabled: {
      type: Boolean,
      default: false,
    },
  },
  watch: {
    value: {
      immediate: true,
      async handler(value) {
        if (this.list.length === 0) {
          await this.getList()
        }
        this.$nextTick(() => {
          if (Array.isArray(value)) {
            value.forEach((i) => {
              this.$refs.tree.setChecked(i, true, false)
            })
          }
        })
      },
    },
    disabled(value) {
      this.setDisabled(this.list, value)
    },
  },
  data() {
    return {
      defaultProps: {
        children: 'children',
        label: 'menuName',
      },
      list: [],
    }
  },
  methods: {
    onCheckChange() {
      const checkedNodes = this.$refs.tree.getCheckedNodes(false, true)
      const checkedKeys = checkedNodes.map((i) => i.id)
      this.$emit('input', checkedKeys)
      this.$emit('change', checkedKeys)
    },
    async getList() {
      const { code, data } = await this.$elBusHttp.request(
        'flower/api/menu/list'
      )
      if (code === 0) {
        const list = data || []
        if (this.disabled) {
          this.setDisabled(list)
        }
        this.list = list
      }
    },
    setDisabled(list, disabled = true) {
      list.forEach((item) => {
        item.disabled = disabled
        if (Array.isArray(item.children) && item.children.length > 0) {
          this.setDisabled(item.children)
        }
      })
    },
  },
}
</script>

<style scoped></style>
